
.. raw:: latex

    \newpage

.. only:: not latex

    =============
    Zahvala
    =============

.. Prevent inclusion of this "title" into index
.. raw:: latex

    \chapter*{Zahvala}

Rad bi se zahvalil mentorju za nudenje podpore in pomoč pri izdelavi diplomskega dela. Prav tako bi se rad zahvalil
vsem ostalim profesorjem, ki so nas poučevali in nudili strokovno podporo v zadnjih treh letih.
Nazadnje bi se rad zahvalil staršema, ki sta me ves čas podpirala.

.. raw:: latex

    \newpage
